package Bundle::Personal::lze;

$VERSION = '0.04';

1;

__END__

=head1 NAME

Bundle::Personal::lze

=head1 SYNOPSIS

perl -MCPAN -e 'install Bundle::Personal::lze'

=head1 CONTENTS


Apache::DB

Apache2::Status

Authen::Captcha

CGI

CGI::QuickForm

Complete::Bash

Complete::Util

CPAN::Uploader

Module::CPANTS::Analyse

Module::CPANTS::Kwalitee

DBI

Frontier::RPC2

GD

Getopt::Long

HTML::Menu::TreeView

HTML::Parser

IO::Prompter

LWP::UserAgent

MD5

Mail::Sendmail

Module::Build

MySQL::Admin

Pod::Usage

Search::Tools::UTF8

Syntax::Highlight::Engine::Kate

Syntax::Highlight::Perl

Term::ANSIColor

Term::Bash::Completion::Generator

Test::More

Test::Pod

Test::Pod::Coverage

URI

XML::RSS

XML::Twig

XML::XSLT



=head1 DESCRIPTION

Personal Modulebundle

=head1 SEE ALSO

http://lindnerei.de

=head1 AUTHOR

Dirk Lindner, dirk.lze@gmail.com
